---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

## Description of the Bug Report

## Checklist

- [ ] Certain that this is a bug (if unsure or you have a question use [discussions](https://github.com/django-json-api/django-rest-framework-json-api/discussions) instead)
- [ ] Code snippet or unit test added to reproduce bug
